@@ -29,14 +29,14 @@ ethseq.Analysis <- function(
   target.vcf = NA,
   target.gds = NA,
   bam.list = NA,
-  out.dir = "/tmp",
+  out.dir = tempdir(),
   model.gds = NA,
   model.available = NA,
   model.assembly = 'hg38',
   model.pop = 'All',
-  model.folder = "/tmp",
+  model.folder = tempdir(),
   run.genotype = FALSE,
-  aseq.path = "/tmp",
+  aseq.path = tempdir(),
   mbq=20,
   mrq=20,
   mdc=10,
